pub struct ShaderPresetPack {
pub language: ShaderSourceLanguage,
pub pass_count: i32,
pub passes: Vec<PassResource>,
pub textures: Vec<TextureResource>,
pub parameters: Vec<ParameterMeta>,
}Expand description
A fully loaded-in-memory shader preset, with all paths resolved to data.
Fields
language: ShaderSourceLanguageThe language that the pass shader sources are in.
Almost always GLSL, unless created from a .wgsl.slangpkg
pass_count: i32The number of shaders enabled in the filter chain.
passes: Vec<PassResource>Preset information for each shader.
textures: Vec<TextureResource>Preset information for each texture.
parameters: Vec<ParameterMeta>Preset information for each user parameter.
Implementations
Sourceimpl ShaderPresetPack
impl ShaderPresetPack
Sourcepub fn load_from_preset<E>(preset: ShaderPreset) -> Result<ShaderPresetPack, E>
pub fn load_from_preset<E>(preset: ShaderPreset) -> Result<ShaderPresetPack, E>
Load a ShaderPack from a ShaderPreset.